@@ -24,8 +24,8 @@ package_directory = os.path.dirname(os.path.abspath(__file__))
 _relax_types = ["D_f", "D_ic", "A_f", "A_ic", "q"]
 
 _schema = {
-    "title": "Fluorburst",
-    "description": "Parameters for Fluorburst to calculate FRET efficiencies and anisotropy decays from MD simulations",
+    "title": "Burst",
+    "description": "Parameters to calculate FRET efficiencies and anisotropy decays from MD simulations",
     "type": "object",
     "properties": {
         "dyes": {
@@ -179,7 +179,7 @@ class Ensemble:
         self.species = []
         ps = parameters["species"]
         for i in range(len(ps["name"])):
-            filelist_rkappa = glob.glob(os.path.join(directory, ps["unix_pattern_rkappa"][i]))
+            filelist_rkappa = sorted(glob.glob(os.path.join(directory, ps["unix_pattern_rkappa"][i])))
             if not filelist_rkappa:
                 raise IndexError(
                     'No rkappa files found for species "{}" with the pattern "{}" in the directory "{}".'.format(
@@ -188,8 +188,8 @@ class Ensemble:
                 )
 
             if compute_anisotropy:
-                filelist_don_coords = glob.glob(os.path.join(directory, ps["unix_pattern_don_coords"][i]))
-                filelist_acc_coords = glob.glob(os.path.join(directory, ps["unix_pattern_acc_coords"][i]))
+                filelist_don_coords = sorted(glob.glob(os.path.join(directory, ps["unix_pattern_don_coords"][i])))
+                filelist_acc_coords = sorted(glob.glob(os.path.join(directory, ps["unix_pattern_acc_coords"][i])))
                 if (not filelist_don_coords) or (not filelist_acc_coords):
                     raise NameError(
                         'No dye coordinates files found for species "{}" with the pattern "{}" or "{}" in the directory "{}".'.format(
@@ -272,11 +272,11 @@ class Species:
         self.trajectories = []
         total_frames = 0
         for i, rkappa_filename in enumerate(filelist_rkappa):
-            try:
+            if filelist_don_coords and filelist_acc_coords:
                 traj = Trajectory.from_file(
                     rkappa_filename, filelist_don_coords[i], filelist_acc_coords[i], units=units
                 )
-            except TypeError:
+            else:
                 traj = Trajectory.from_file(rkappa_filename, units=units)
 
             if n_trajectory_splits:
@@ -341,7 +341,7 @@ class Trajectory:
 
     @classmethod
     def from_file(cls, rkappa_filename, don_coords_filename=None, acc_coords_filename=None, units="A"):
-        """Create a fluordynamics.fluorburst.Trajectory class from filenames
+        """Create a burst.Trajectory class from filenames
 
         Parameters
         ----------
@@ -395,7 +395,9 @@ class Trajectory:
         all_lengths = [traj_length, len(donor_xyz[:, 0]), len(acceptor_xyz[:, 0])]
         if all_lengths[1:] != all_lengths[:-1]:
             raise ValueError(
-                "Length of rkappa and dye coordinates is not the same [{}].".format(", ".join(all_lengths))
+                f"Length of rkappa and dye coordinates is not the same:\nrkappa: {all_lengths[0]}, donor coordinates: {all_lengths[1]}, acceptor coordinates: {all_lengths[2]}".format(
+                    all_lengths
+                )
             )
 
     @staticmethod
@@ -532,7 +534,7 @@ class Relaxation:
 
     Parameters
     ----------
-    trajectory : fluordynamics.burst.Trajectory
+    trajectory : burst.Trajectory
         trajectory object containing inter-dye distances, kappasquare values and donor/acceptor dye transition dipoles
     pD_tot : float
         probability of a donor relaxation event (photon emission + internal conversion)
@@ -879,7 +881,7 @@ class Experiment:
 
         Returns
         -------
-        fluordynamics.fluorburst.Burst
+        burst.Burst
             Burst object containing a series of relaxation events with associated decaytimes, polarizations and FRET efficiencies
         """
         burst = Burst(burstsize, self.parameters["dyes"]["QD"], self.parameters["dyes"]["QA"])
